@@ -1,7 +1,7 @@
 // main.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2008, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,9 +28,14 @@
 #include <QTranslator>
 #include <QLocale>
 
+#if QT_VERSION < 0x040300
+#define lighter(x)	light(x)
+#define darker(x)	dark(x)
+#endif
+
 
 //-------------------------------------------------------------------------
-// Single application instance stuff (Qt/X11 only atm.)
+// Singleton application instance stuff (Qt/X11 only atm.)
 //
 
 #if defined(Q_WS_X11)
@@ -50,7 +55,7 @@ public:
 
 	// Constructor.
 	qsynthApplication(int& argc, char **argv) : QApplication(argc, argv),
-		m_pQtTranslator(0), m_pMyTranslator(0), m_pWidget(0)	
+		m_pQtTranslator(0), m_pMyTranslator(0), m_pWidget(0)
 	{
 		// Load translation support.
 		QLocale loc;
@@ -66,9 +71,9 @@ public:
 				m_pQtTranslator = 0;
 		#ifdef CONFIG_DEBUG
 				qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
-					loc.name().toUtf8().constData(),
-					sLocPath.toUtf8().constData(),
-					sLocName.toUtf8().constData());
+					loc.name().toLocal8Bit().data(),
+					sLocPath.toLocal8Bit().data(),
+					sLocName.toLocal8Bit().data());
 		#endif
 			}
 			// Try own application translation...
@@ -85,9 +90,9 @@ public:
 					m_pMyTranslator = 0;
 		#ifdef CONFIG_DEBUG
 					qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
-						loc.name().toUtf8().constData(),
-						sLocPath.toUtf8().constData(),
-						sLocName.toUtf8().constData());
+						loc.name().toLocal8Bit().data(),
+						sLocPath.toLocal8Bit().data(),
+						sLocName.toLocal8Bit().data());
 		#endif
 				}
 			}
@@ -213,7 +218,7 @@ public:
 		return QApplication::x11EventFilter(pEv);
 	}
 #endif
-	
+
 private:
 
 	// Translation support.
@@ -241,7 +246,7 @@ int main ( int argc, char **argv )
 
 	// Construct default settings; override with command line arguments.
 	qsynthOptions settings;
-	if (!settings.parse_args(app.argc(), app.argv())) {
+	if (!settings.parse_args(app.arguments())) {
 		app.quit();
 		return 1;
 	}
@@ -252,14 +257,35 @@ int main ( int argc, char **argv )
 		return 2;
 	}
 
+	// Dark themes grayed/disabled color group fix...
+	QPalette pal(app.palette());
+	if (pal.base().color().value() < 0x7f) {
+		pal.setColorGroup(QPalette::Disabled,
+			pal.windowText().color().darker(),
+			pal.button(),
+			pal.light(),
+			pal.dark(),
+			pal.mid(),
+			pal.text().color().darker(),
+			pal.text().color().lighter(),
+			pal.base(),
+			pal.window());
+		app.setPalette(pal);
+	}
+
 	// Set default base font...
+	int iBaseFontSize = app.font().pointSize();
 	if (settings.iBaseFontSize > 0)
-		app.setFont(QFont(app.font().family(), settings.iBaseFontSize));
+		iBaseFontSize = settings.iBaseFontSize;
+	app.setFont(QFont(app.font().family(), iBaseFontSize));
 
 	// What style do we create these forms?
 	Qt::WindowFlags wflags = Qt::Window
 #if QT_VERSION >= 0x040200
 		| Qt::CustomizeWindowHint
+#if QT_VERSION >= 0x040500
+		| Qt::WindowCloseButtonHint
+#endif
 #endif
 		| Qt::WindowTitleHint
 		| Qt::WindowSystemMenuHint
@@ -268,7 +294,6 @@ int main ( int argc, char **argv )
 		wflags |= Qt::Tool;
 	// Construct the main form, and show it to the world.
 	qsynthMainForm w(0, wflags);
-//	app.setMainWidget(&w);
 	w.setup(&settings);
 	// If we have a systray icon, we'll skip this.
 	if (!settings.bSystemTray) {
@@ -280,7 +305,6 @@ int main ( int argc, char **argv )
 	app.setMainWidget(&w);
 
 	// Register the quit signal/slot.
-	// app.connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));
 	app.setQuitOnLastWindowClosed(false);
 
 	return app.exec();
