@@ -1,7 +1,7 @@
 // qsynthMainForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -36,6 +36,7 @@
 #include "qsynthDialClassicStyle.h"
 #include "qsynthDialVokiStyle.h"
 #include "qsynthDialPeppinoStyle.h"
+#include "qsynthDialSkulptureStyle.h"
 
 #include <QApplication>
 #include <QSocketNotifier>
@@ -310,7 +311,7 @@ static fluid_sfont_t *qsynth_sfloader_load (
 		}
 		pNode = pNode->pNext;
 	}
-	
+
 	// fluidsynth will call next (or default) loader...
 	return NULL;
 }
@@ -519,7 +520,7 @@ qsynthMainForm::~qsynthMainForm (void)
 
 	// Pseudo-singleton reference shut-down.
 	g_pMainForm = NULL;
-	
+
 	if (m_pKnobStyle)
 		delete m_pKnobStyle;
 }
@@ -544,6 +545,9 @@ void qsynthMainForm::setup ( qsynthOptions *pOptions )
 	Qt::WindowFlags wflags = Qt::Window
 #if QT_VERSION >= 0x040200
  		| Qt::CustomizeWindowHint
+#if QT_VERSION >= 0x040500
+		| Qt::WindowCloseButtonHint
+#endif
 #endif
 		| Qt::WindowTitleHint
 		| Qt::WindowSystemMenuHint
@@ -582,7 +586,7 @@ void qsynthMainForm::setup ( qsynthOptions *pOptions )
 
 	// Knobs
 	updateKnobs();
-	
+
 #if !defined(WIN32)
 	// Check if we can redirect our own stdout/stderr...
 	if (m_pOptions->bStdoutCapture && ::pipe(g_fdStdout) == 0) {
@@ -647,7 +651,8 @@ bool qsynthMainForm::queryClose (void)
 						QSYNTH_TITLE ": " + tr("Warning"),
 						QSYNTH_TITLE " " + tr("is about to terminate.") + "\n\n" +
 						tr("Are you sure?"),
-						tr("OK"), tr("Cancel")) == 0);
+						QMessageBox::Ok | QMessageBox::Cancel)
+						== QMessageBox::Ok);
 					break;
 				}
 			}
@@ -714,13 +719,13 @@ void qsynthMainForm::playLoadFiles ( qsynthEngine *pEngine,
 	while (iter.hasNext()) {
 		const QString& sFilename = iter.next();
 		// Is it a soundfont file...
-		if (::fluid_is_soundfont(sFilename.toUtf8().data())) {
+		if (::fluid_is_soundfont(sFilename.toLocal8Bit().data())) {
 			if (bSetup || !pSetup->soundfonts.contains(sFilename)) {
 				appendMessagesColor(sPrefix +
 					tr("Loading soundfont: \"%1\"")
 					.arg(sFilename) + sElipsis, "#999933");
 				if (::fluid_synth_sfload(
-						pEngine->pSynth, sFilename.toUtf8().data(), 1) >= 0) {
+						pEngine->pSynth, sFilename.toLocal8Bit().data(), 1) >= 0) {
 					iSoundFonts++;
 					if (!bSetup) {
 						pSetup->soundfonts.append(sFilename);
@@ -734,12 +739,12 @@ void qsynthMainForm::playLoadFiles ( qsynthEngine *pEngine,
 			}
 		}
 		else  // Or is it a bare midifile?
-		if (::fluid_is_midifile(sFilename.toUtf8().data()) && pEngine->pPlayer) {
+		if (::fluid_is_midifile(sFilename.toLocal8Bit().data()) && pEngine->pPlayer) {
 			appendMessagesColor(sPrefix +
 				tr("Playing MIDI file: \"%1\"")
 				.arg(sFilename) + sElipsis, "#99cc66");
 			if (::fluid_player_add(
-					pEngine->pPlayer, sFilename.toUtf8().data()) >= 0) {
+					pEngine->pPlayer, sFilename.toLocal8Bit().data()) >= 0) {
 				iMidiFiles++;
 			} else {
 				appendMessagesError(sPrefix +
@@ -773,7 +778,7 @@ void qsynthMainForm::dragEnterEvent ( QDragEnterEvent* pDragEnterEvent )
 				const QString& sFilename
 					= iter.next().toLocalFile();
 				if (!sFilename.isEmpty()) {
-					char *pszFilename = sFilename.toUtf8().data();
+					char *pszFilename = sFilename.toLocal8Bit().data();
 					if (::fluid_is_midifile(pszFilename) ||
 						::fluid_is_soundfont(pszFilename))
 						bAccept = true;
@@ -878,7 +883,7 @@ void qsynthMainForm::appendMessagesError( const QString& s )
 	appendMessagesColor(s.simplified(), "#ff0000");
 
 	QMessageBox::critical(this,
-		QSYNTH_TITLE ": " + tr("Error"), s, tr("Cancel"));
+		QSYNTH_TITLE ": " + tr("Error"), s, QMessageBox::Cancel);
 }
 
 
@@ -922,7 +927,7 @@ void qsynthMainForm::updateOutputMeters (void)
 	else
 		m_ui.OutputGroupBox->hide();
 
-	adjustSize();
+//	adjustSize();
 }
 
 
@@ -1196,7 +1201,8 @@ bool qsynthMainForm::deleteEngineTab ( qsynthEngine *pEngine, int iTab )
 		tr("Delete fluidsynth engine:") + "\n\n" +
 		pEngine->name() + "\n\n" +
 		tr("Are you sure?"),
-		tr("OK"), tr("Cancel")) == 0);
+		QMessageBox::Ok | QMessageBox::Cancel)
+		== QMessageBox::Ok);
 
 	if (bResult) {
 		// First we try to stop the angine.
@@ -1334,7 +1340,7 @@ void qsynthMainForm::showOptionsForm (void)
 		if (m_pOptions->sMessagesFont.isEmpty() && m_pMessagesForm)
 			m_pOptions->sMessagesFont = m_pMessagesForm->messagesFont().toString();
 		// To track down deferred or immediate changes.
-		bool    bOldMessagesLog = m_pOptions->bMessagesLog; 
+		bool    bOldMessagesLog = m_pOptions->bMessagesLog;
 		QString sOldMessagesLogPath = m_pOptions->sMessagesLogPath;
 		QString sMessagesFont  = m_pOptions->sMessagesFont;
 		bool    bSystemTray    = m_pOptions->bSystemTray;
@@ -1359,7 +1365,7 @@ void qsynthMainForm::showOptionsForm (void)
 				QMessageBox::information(this,
 					QSYNTH_TITLE ": " + tr("Information"),
 					tr("Some settings will be only effective\n"
-					"next time you start this program."), tr("OK"));
+					"next time you start this program."));
 			}
 			// Check wheather something immediate has changed.
 			if (( bOldMessagesLog && !m_pOptions->bMessagesLog) ||
@@ -1611,19 +1617,19 @@ bool qsynthMainForm::startEngine ( qsynthEngine *pEngine )
 	while (iter.hasNext()) {
 		const QString& sFilename = iter.next();
 		// Is it a soundfont file...
-		if (::fluid_is_soundfont(sFilename.toUtf8().data())) {
+		if (::fluid_is_soundfont(sFilename.toLocal8Bit().data())) {
 			int iBankOffset = pSetup->bankoffsets[i].toInt();
 			appendMessagesColor(sPrefix +
 				tr("Loading soundfont: \"%1\" (bank offset %2)")
 				.arg(sFilename).arg(iBankOffset) + sElipsis, "#999933");
 			int iSFID = ::fluid_synth_sfload(
-				pEngine->pSynth, sFilename.toUtf8().data(), 1);
+				pEngine->pSynth, sFilename.toLocal8Bit().data(), 1);
 			if (iSFID < 0)
 				appendMessagesError(sPrefix +
 					tr("Failed to load the soundfont: \"%1\".")
 					.arg(sFilename));
 #ifdef CONFIG_FLUID_BANK_OFFSET
-			else 
+			else
 			if (::fluid_synth_set_bank_offset(
 				pEngine->pSynth, iSFID, iBankOffset) < 0) {
 				appendMessagesError(sPrefix +
@@ -1711,21 +1717,21 @@ bool qsynthMainForm::startEngine ( qsynthEngine *pEngine )
 #ifdef CONFIG_FLUID_SERVER
 		appendMessages(sPrefix + tr("Creating server") + sElipsis);
 		// Server port must be different for each engine...
-		char *pszShellPort = "shell.port";
+		char szShellPort[] = "shell.port";
 		if (g_iLastShellPort > 0) {
 			g_iLastShellPort++;
 		} else {
 			g_iLastShellPort = 0;
 			::fluid_settings_getint(
-				pSetup->fluid_settings(), pszShellPort, &g_iLastShellPort);
+				pSetup->fluid_settings(), szShellPort, &g_iLastShellPort);
 			if (g_iLastShellPort == 0) {
 				g_iLastShellPort = ::fluid_settings_getint_default(
-					pSetup->fluid_settings(), pszShellPort);
+					pSetup->fluid_settings(), szShellPort);
 			}
 		}
 		// Set the (new) server port for this engne...
 		::fluid_settings_setint(
-			pSetup->fluid_settings(), pszShellPort, g_iLastShellPort);
+			pSetup->fluid_settings(), szShellPort, g_iLastShellPort);
 		// Create the server now...
 		pEngine->pServer = ::new_fluid_server(
 			pSetup->fluid_settings(), qsynth_newclient, pEngine->pSynth);
@@ -1741,7 +1747,7 @@ bool qsynthMainForm::startEngine ( qsynthEngine *pEngine )
 	}
 
 	// Make an initial program reset.
-	resetEngine(pEngine);
+	m_pOptions->loadPreset(pEngine, pSetup->sDefPreset);
 
 	// Show up our efforts, if we're currently selected :)
 	if (pEngine == currentEngine()) {
@@ -1923,7 +1929,7 @@ void qsynthMainForm::restartAllEngines (void)
 			tr("Please note that this operation may cause\n"
 			"temporary MIDI and Audio disruption.") + "\n\n" +
 			tr("Do you want to restart all engines now?"),
-			tr("Yes"), tr("No")) == 0);
+			QMessageBox::Yes | QMessageBox::No) == QMessageBox::Yes);
 
 	// Just restart every engine out there...
 	if (bRestart) {
@@ -1953,7 +1959,7 @@ void qsynthMainForm::restartEngine ( qsynthEngine *pEngine )
 			tr("Please note that this operation may cause\n"
 			"temporary MIDI and Audio disruption.") + "\n\n" +
 			tr("Do you want to restart the engine now?"),
-			tr("Yes"), tr("No")) == 0);
+			QMessageBox::Yes | QMessageBox::No) == QMessageBox::Yes);
 	}
 
 	// If allowed, just restart the engine...
@@ -2382,9 +2388,9 @@ void qsynthMainForm::contextMenuEvent( QContextMenuEvent *pEvent )
 void qsynthMainForm::updateKnobs()
 {
 	if (m_pOptions == NULL)
-		return;	
+		return;
 	qsynthKnob::DialMode mode = qsynthKnob::DialMode(m_pOptions->iKnobMotion);
-	KnobStyle style = KnobStyle(m_pOptions->iKnobStyle); 
+	KnobStyle style = KnobStyle(m_pOptions->iKnobStyle);
 	if (m_pKnobStyle) {
 		delete m_pKnobStyle;
 	}
@@ -2398,6 +2404,9 @@ void qsynthMainForm::updateKnobs()
 	case Peppino:
 		m_pKnobStyle = new qsynthDialPeppinoStyle();
 		break;
+	case Skulpture:
+	    m_pKnobStyle = new qsynthDialSkulptureStyle();
+	    break;
 	default:
 		m_pKnobStyle = NULL;
 		break;
