@@ -1,7 +1,7 @@
 // qsynthMainForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -70,8 +70,8 @@ public:
 	void restartEngine(qsynthEngine *pEngine);
 	void resetEngine(qsynthEngine *pEngine);
 
-	enum KnobStyle { Classic, Vokimon, Peppino, Legacy };
-	
+	enum KnobStyle { Classic, Vokimon, Peppino, Skulpture, Legacy };
+
 public slots:
 
 	void stdoutNotifySlot(int);
@@ -188,8 +188,8 @@ private:
 
 	// Kind-of singleton reference.
 	static qsynthMainForm *g_pMainForm;
-	
-	// Style for qsynthKnob (QDial) widgets 
+
+	// Style for qsynthKnob (QDial) widgets
 	QStyle* m_pKnobStyle;
 };
 
